@@ -40,23 +40,30 @@ async def get_reps_texts_async(urls ,
 ##
 # getting resp json async funcs
 
-async def get_a_resp_json_async(url , trust_env , params , verify_ssl) :
+async def get_a_resp_json_async(url ,
+                                trust_env ,
+                                params ,
+                                verify_ssl ,
+                                content_type
+                                ) :
   async with ClientSession(trust_env = trust_env) as ses :
     async with ses.get(url ,
                        params = params ,
                        verify_ssl = verify_ssl) as resp :
-      return await resp.json()
+      return await resp.json(content_type = content_type)
 
 
 async def get_reps_jsons_async(urls ,
                                trust_env = False ,
                                params = None ,
-                               verify_ssl = True
+                               verify_ssl = True ,
+                               content_type = None
                                ) :
   fu = partial(get_a_resp_json_async ,
                trust_env = trust_env ,
                params = params ,
-               verify_ssl = verify_ssl)
+               verify_ssl = verify_ssl ,
+               content_type = content_type)
 
   co_tasks = [fu(x) for x in urls]
 
